refloraR::reflora_download()reflora_download
Download plant specimen records from REFLORA Virtual Herbarium
Description
Download plant specimen records in Darwin Core Format from any herbarium collection at REFLORA Virtual Herbarium hosted by the Rio de Janeiro Botanical Garden. REFLORA aggregates collections from both Brazilian and international herbaria that hold Brazilian specimens.
Arguments
| Argument | Description |
|---|---|
| herbarium | A vector of specific herbarium acronyms (collection code) in uppercase letters or leave it as NULL to download records for all REFLORA herbaria. |
| repatriated | Logical. If FALSE, skips downloading records from REFLORA-associated herbaria that have been repatriated. Default is TRUE. Use reflora_summary() to check which collections are repatriated. In this context, “digital repatriation” refers to making high-resolution images and associated specimen metadata openly accessible through a Brazilian public infrastructure (HVR/IPT). |
| verbose | Logical, if FALSE, a message showing steps when downloading herbarium specimen records will not be printed in the console in full. |
| dir | Pathway to the computer’s directory, where the file will be saved. The default is to create a directory named reflora_download and the results will be saved within a subfolder named by each searched REFLORA-associated herbarium collection. |
Value
Invisibly returns NULL. This function is called for downloading and extracting Darwin Core Archive (DwC-A) files into the specified directory.
Examples
reflora_download(herbarium = c("ALCB", "HUEFS", "K", "RB"),
verbose = TRUE,
dir = "reflora_download")