reflora_parse

Parse Darwin Core Archive files
refloraR::reflora_parse()

Description

Read Darwin Core Archive (DwC-A) files from any downloaded dwca folder at REFLORA Virtual Herbarium hosted by the Rio de Janeiro Botanical Garden.

Arguments

Argument Description
path Pathway to the computer’s directory, where the REFLORA-downloaded dwca folders are.
herbarium A vector of specific herbarium acronyms (collection code) in uppercase letters or leave it as NULL to parse specimen records for all herbarim dcwa folders in the defined path directory.
repatriated Logical. If FALSE, skips downloading records from REFLORA-associated herbaria that have been repatriated. Default is TRUE. Use reflora_summary() to check which collections are repatriated. REFLORA aggregates collections from both Brazilian and international herbaria that hold Brazilian specimens. In this context, “digital repatriation” refers to making high-resolution images and associated specimen metadata openly accessible through a Brazilian public infrastructure (HVR/IPT).
verbose Logical, if FALSE, a message showing steps when summarizing specimen records will not be printed in the console in full.

Value

A named list of Darwin Core Archive objects, one per parsed herbarium collection. Each element corresponds to the output of finch::dwca_read() and contains:

$dataA list of data tables included in the archive, including a cleaned and standardized occurrence.txt data frame with selected Darwin Core fields. $metaMetadata extracted from the archive’s EML file. $filesInformation about the archive structure and associated files.

The returned list is named by herbarium collection codes. When available, associated summary CSV files (generated by reflora_download()) are appended as additional elements within each herbarium object.

Examples

reflora_download(herbarium = c("ALCB", "HUEFS", "K", "RB"),
                 verbose = TRUE,
                 dir = "reflora_download")

dwca <- reflora_parse(path = "reflora_download",
                      verbose = TRUE)